fsutil

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AtomicWriteFile

func AtomicWriteFile(path string, data []byte, mode os.FileMode) error

AtomicWriteFile writes data to path by using a temporary file in the same directory and renaming it into place after the write succeeds.

Types

This section is empty.

Jump to